@@ -2,29 +2,34 @@ package Dancer::Plugin::TimeoutManager;
 
 use strict;
 use warnings;
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 use Try::Tiny;
 use Dancer ':syntax';
 use Dancer::Exception ':all';
 use Dancer::Plugin;
-use Data::Dumper;
 use Carp 'croak';
 use List::MoreUtils qw( none);
 
+
+if (  exists $ENV{DISABLE_DANCER_TIMEOUT} && $ENV{DISABLE_DANCER_TIMEOUT} ) {
+    set disable_timeout => 1;
+}
+
 #get the timeout from headers
-hook(before => sub { 
+hook(before => sub {
     var header_timeout => request->header('X-Dancer-Timeout');
 });
 
 register 'timeout' => \&timeout;
 
 register_exception ('InvalidArgumentNumber',
-        message_pattern => "the number of arguments must 3 or 4, you've got %s",
-        );
+    message_pattern => "the number of arguments must 3 or 4, you've got %s",
+);
+
 register_exception ('InvalidMethod',
-        message_pattern => "method must be one in get, put, post, delete and %s is used as a method",
-        );
+    message_pattern => "method must be one in get, put, post, delete and %s is used as a method",
+);
 
 
 my @authorized_methods = ('get', 'post', 'put', 'delete');
@@ -34,9 +39,9 @@ my @authorized_methods = ('get', 'post', 'put', 'delete');
 return the exception message
 This method can be used to catch the exception if the code used already contained a try catch
 
-=cut 
+=cut
 
-sub exception_message{
+sub exception_message {
 
     return 'Route Timeout Detected';
 }
@@ -45,43 +50,51 @@ sub exception_message{
 
 Method that manage the timeout on a dancer request
 
-=cut 
+=cut
 
 sub timeout {
     my ($timeout,$method, $pattern, @rest);
-    if (scalar(@_) == 4){
+
+    if (scalar(@_) == 4) {
         ($timeout,$method, $pattern, @rest) = @_;
     }
-    elsif(scalar(@_) == 3){
+    elsif(scalar(@_) == 3) {
         ($method, $pattern, @rest) = @_;
     }
-    else{
+    else {
          raise InvalidMethod => scalar(@_);
     }
+
     my $code;
     for my $e (@rest) { $code = $e if (ref($e) eq 'CODE') }
     my $request;
 
     #if method is not valid an exception is done
-    if ( none { $_ eq lc($method) } @authorized_methods ){
+    if ( none { $_ eq lc($method) } @authorized_methods ) {
         raise InvalidMethod => $method;
     }
-    
+
     my $exception_message = exception_message();
     my $timeout_route = sub {
         my $response;
 
+        # maximum possible timeout, set in the plugin config
+        my $conf = plugin_setting();
+
         #if timeout is not defined but a value is set in the headers for timeout
         my $request_timeout = 0;
         $request_timeout = $timeout if (defined $timeout);
         $request_timeout = vars->{header_timeout} if (!defined $timeout && defined vars->{header_timeout});
+        $request_timeout = $conf->{max_timeout}
+          if (defined $conf->{max_timeout} && defined $request_timeout && $request_timeout && $conf->{max_timeout} < $request_timeout);
 
         # if timeout is not defined or equal 0 the timeout manager is not used
         my $timeout_exception;
-        if (!$request_timeout){
+
+        if (!$request_timeout || (defined setting('disable_timeout') && setting('disable_timeout'))) {
             $response = $code->();
         }
-        else{
+        else {
            try {
                 local $SIG{ALRM} = sub { croak ($exception_message); };
                 alarm($request_timeout);
@@ -89,19 +102,22 @@ sub timeout {
                 $response = $code->();
                 alarm(0);
             }
-            catch{
+            catch {
                 $timeout_exception = $_;
             };
+
             alarm(0);
         }
+
         # Timeout detected
-        if ($timeout_exception && $timeout_exception =~ /$exception_message/){
+        if ($timeout_exception && $timeout_exception =~ /$exception_message/) {
             my $response_with_timeout = Dancer::Response->new(
-                    status => 408,
-                    content => "Request Timeout : more than $request_timeout seconds elapsed."
-                    );
+                status  => 408,
+                content => "Request Timeout : more than $request_timeout seconds elapsed."
+            );
             return $response_with_timeout;
         }
+
         # Preserve exceptions caught during route call
         croak $@ if $@;
 
@@ -109,8 +125,8 @@ sub timeout {
         return $response;
     };
 
-
     my @compiled_rest;
+
     for my $e (@rest) {
         if (ref($e) eq 'CODE') {
             push @compiled_rest, $timeout_route;
@@ -126,7 +142,6 @@ sub timeout {
 
 register_plugin;
 
-
 1;
 __END__
 =head1 NAME
@@ -138,7 +153,7 @@ Dancer::Plugin::TimeoutManager - Plugin to define route handlers with a timeout
 
   use Dancer;
   use Dancer::Plugin::TimeoutManager;
-  
+
   # if somecode() takes more than 1 second, execustion flow will be stoped and a 408 returned
   timeout 1, 'get' => '/method' => sub {
       somecode();
@@ -149,20 +164,26 @@ Dancer::Plugin::TimeoutManager - Plugin to define route handlers with a timeout
     my $code;
   };
 
- 
+
 =head1 DESCRIPTION
 
 This plugins allows to define route handlers with a maximum amount of time for the code execution.
 
-If that time is elapsed and the code of the route still runs, the execution flow is stopped and a 
+If that time is elapsed and the code of the route still runs, the execution flow is stopped and a
 default 408 response is returned.
 
 If the timeout is set to 0, the behavior is the same than without any timeout defined.
 
-It's also possible to define route handlers that will set a per-request timeout protection, depending 
+It's also possible to define route handlers that will set a per-request timeout protection, depending
 on the value of the header C<X-Dancer-Timeout>.
 
-If your Dancer code already use try catch, the exeption may be catched. 
+If config variable C<max_timeout> set - timeouts will be limitet to be no more than c<max_timeout> value.
+If no timeout set, C<max_timeout> is ignored.
+
+Also environment variable C<DISABLE_DANCER_TIMEOUT> can be used to turn off all timeouts in C<Dancer>
+application.
+
+If your Dancer code already use try catch, the exeption may be catched.
 So exception_message method can be used to cath the content of the exception in your Dancer code.
 
 =head1 AUTHOR
